<?php


/************************ Theme Initial setup ***********************************/

add_action ('after_setup_theme','softlights_theme_setup');


function softlights_theme_setup () {

add_theme_support('post-thumbnails');
set_post_thumbnail_size(150, 150, true);
add_theme_support( 'automatic-feed-links' );

if ( ! isset( $content_width ) )
	$content_width = 600;
	
$softlights_settings = get_option('softlights-options');

if($softlights_settings === false) {
	$softlights_settings = softlights_defaults();
}
	
update_option('softlights-options', $softlights_settings);

	
}	

/****************** Initialize Theme Default Values **************************************/

function softlights_defaults() {

$defaults = array (
				'logo' => '',
				'favicon' => '',
				'footer' => '',
				'facebook-link' => '',
				'twitter-link' => '',
				'google-plus-link' => '',
				'pin-it-link' => '',
				'linkedin-link' => '',
				'showcase-image' => '',
				'showcase-title' => '',
				'showcase-text' => '',
				'showcase-link' => '',
				'menu-color' => '#caeffc',
				'header-color' => 'transparent',
				'menu-font-color' => '#333',
				'widgets-menus-color' => '#f2f2f2',
				'footer-color' => '#b7d3e5',
				'link-color' => '#000',
				'content-link-color' => '#cc0000',
				'bg-color' => 'transparent',
				'showcase-color' => '#f5fefe',
				'showcase-font-color' => '#777',
				'showcase' => '0',
				'comments' => '1',
				'reset' => '0'
				);
				
return $defaults;					
	
}	
	



/********************************* Excerpts fix *******************************/

add_filter('excerpt_more', 'softlights_new_excerpt_more');

function softlights_new_excerpt_more( $more ) {
	return '';
}


/***************************** Admin Theme Options Scripts *************************/

add_action( 'admin_enqueue_scripts', 'softlights_admin_scripts' );

function softlights_admin_scripts($hook) {
	
	if('appearance_page_sl-theme-options' != $hook) {
		return;
	}

   wp_enqueue_script( 'iris',get_template_directory_uri().'/js/iris.min.js' );
   wp_enqueue_script( 'iris-init',get_template_directory_uri().'/js/iris-init.js' );
   wp_enqueue_style ('admin-css', get_template_directory_uri() . '/admin-style.css');
     
   wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
		wp_enqueue_style('thickbox');
	 wp_enqueue_script('uploader', get_template_directory_uri().'/js/uploader.js');
}

/*********************** Fix Admin bar for messing with absolute elements ******************/

add_action('get_header', 'softlights_wp_adminbar_fix');

function softlights_wp_adminbar_fix() {
    remove_action('wp_head', '_admin_bar_bump_cb');
}

/************************* Theme Custom Colors ************************************/

function softlights_custom_styles() {
	
	
	$softlights_options = get_option('softlights-options');
	
	echo '<style>nav ul li a { color:'. esc_html($softlights_options['menu-font-color']) .' !important }</style>';
	echo '<style>nav ul li ul li a, nav {background:'. esc_html($softlights_options['menu-color']) .'}
</style>';
	echo '<style>#header {background:'. esc_html($softlights_options['header-color']) .'}</style>';
	echo '<style>.widget { background:'. esc_html($softlights_options['widgets-menus-color']) .'}</style>';
	echo '<style>#footer {background:'. esc_html($softlights_options['footer-color']) .'}</style>';
	echo '<style> a {color:'. esc_html($softlights_options['link-color']) .' }</style>';
	echo '<style>.thecontent a {color:'. esc_html($softlights_options['content-link-color']) .'!important }</style>';
	echo '<style>body {background:'. esc_html($softlights_options['bg-color']) .'}</style>';
	echo '<style>.showcasebox,.frontheader { background:'. esc_html($softlights_options['showcase-color']) .'}</style>';
	echo '<style>.showcasebox, .showcasebox h2 { color:'. $softlights_options['showcase-font-color'] . '}</style>';
	
	
}

add_action('wp_head','softlights_custom_styles');


/********************************** Theme Setup scripts, Fonts and styles ************************************/

function softlights_scripts_styles()
{
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
	
	wp_register_style('softlights-fonts','http://fonts.googleapis.com/css?family=PT+Sans|Oswald|Roboto+Condensed');
	
	wp_enqueue_style( 'default', get_stylesheet_uri() ); // default stylesheet
	wp_enqueue_style( 'softlights-fonts');
	

}

add_action ('wp_enqueue_scripts','softlights_scripts_styles');	



/************************** Set Limit to No of Posts ***********************************/

function softlights_posts_on_homepage( $query ) {
    if ( $query->is_main_query() ) {
        $query->set( 'posts_per_page', 12 );
    }
}
add_action( 'pre_get_posts', 'softlights_posts_on_homepage' );


/******************************** Register Navigation menus ***************************/
 
add_action( 'init', 'softlights_nav_menu' );

 function softlights_nav_menu() {
    register_nav_menu( 'primary-menu',  'Primary Menu');
    register_nav_menu( 'top-menu', 'Top Menu' );
    register_nav_menu( 'footer-menu', 'Footer Menu' );
}


/************************** Theme Pagination *************************************/

function softlights_pagination() {
		global $wp_query;

		$big = 999999999; // need an unlikely integer
		
		echo paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var('paged') ),
			'total' => $wp_query->max_num_pages
		) );
	}

	
/********************************* Theme Widgets Setup **********************************/

add_action( 'widgets_init', 'softlights_widgets_init' );

function softlights_widgets_init() {
	
/* Right and Left Sidebars */	
	register_sidebar(array(
  'name' =>  'Right Hand Sidebar',
  'id' => 'right-sidebar',
  'description' => 'Widgets in this area will be shown on the right-hand side.',
  'before_title' => '<h3>',
  'after_title' => '</h3>'
));

register_sidebar(array(
  'name' =>  'Left Hand Sidebar',
  'id' => 'left-sidebar',
  'description' => 'Widgets in this area will be shown on the right-hand side.',
  'before_title' => '<h3>',
  'after_title' => '</h3>'
));


/* Top Widget */

register_sidebar(array(
  'name' =>  'Top Widget',
  'id' => 'top-widget',
  'description' => 'Appears below navigation below.',
  'before_title' => '<h3>',
  'after_title' => '</h3>'
));

	
	/* Footer widgets */
	
	register_sidebar( array(
		'name' =>  'Footer Widget',
		'id' => 'footer-widget',
		'description' => 'Appears above footer. Max 5 boxes of equal size',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );
	
		
	/* Home page widgets */

	register_sidebar( array(
		'name' =>  'Home Widget',
		'id' => 'homepage-widget',
		'description' => 'Appears at the center of homepage above boxed posts',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );

	


}	



/******************************** Filter the Title *******************************/

function softlights_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( 'Page %s', max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'softlights_wp_title', 10, 2 );


/********************************* Theme Admin section *******************************************/

if (is_admin()) {
add_action ('admin_menu', 'softlights_admin_menu');
}

function softlights_admin_menu() {
	
	add_theme_page( 'Theme Option','softlights Options', 'edit_theme_options', 'sl-theme-options', 'softlights_options_page'); 
	add_action( 'admin_init','softlights_register_mysettings' );

}

function softlights_register_mysettings() { // whitelist options
  register_setting( 'softlights-option-group', 'softlights-options' ,'softlights_options_validate');
}

/************************ Validation of admin input data ***********************/

function softlights_options_validate ($input) {

$input['logo'] = esc_url_raw($input['logo']);
$input['favicon'] = esc_url_raw($input['favicon']);

$input['facebook-link'] = esc_url_raw($input['facebook-link']);
$input['twitter-link'] = esc_url_raw($input['twitter-link']);
$input['google-plus-link'] = esc_url_raw($input['google-plus-link']);
$input['pin-it-link'] = esc_url_raw($input['pin-it-link']);
$input['linkedin-linked'] = esc_url_raw($input['linkedin-link']);


$input['showcase-image'] = esc_url_raw($input['showcase-image']);
$input['showcase-title'] = sanitize_text_field($input['showcase-title']);
$input['showcase-text'] = sanitize_text_field($input['showcase-text']);
$input['showcase-link'] = esc_url_raw($input['showcase-link']);

$input['link-color'] = sanitize_text_field($input['link-color']);
$input['content-link-color'] = sanitize_text_field($input['content-link-color']);

$input['bg-color'] = sanitize_text_field($input['bg-color']);
$input['menu-color'] = sanitize_text_field($input['menu-color']);
$input['menu-font-color'] = sanitize_text_field($input['menu-font-color']);
$input['header-color'] = sanitize_text_field($input['header-color']);
$input['footer-color'] = sanitize_text_field($input['footer-color']);
$input['widgets-menus-color'] = sanitize_text_field($input['widgets-menus-color']);
$input['showcase-color'] = sanitize_text_field($input['showcase-color']);

return $input;

}

/****************************** Theme Options Page *********************************/

function softlights_options_page() {
?>	
	<div class="wrap">
<img src="<?php echo get_template_directory_uri().'/images/softlights.png' ?>">

<form method="post" action="options.php"> 
<?php 
settings_fields( 'softlights-option-group' );
do_settings_sections( 'softlights-option-group' );	
				

// Reset default values
if(isset($_POST['reset'])) {
	update_option('softlights-options', softlights_defaults() );
	echo '<p style="color:red">Theme settings have been reset and default values loaded</p>';
}

$softlights_options = get_option('softlights-options');


?>
<div class="tabs">
<label for="one">General (+)</label>
<label for="two">Showcasebox (+)</label>
<label for="three">Theme Colors (+)</label>
<label for="four">Link Colors (+)</label>
</div>
<input type="radio" name="tab" id="one" checked="checked">
<div id="tab1" class="tab">

           <p>Please upload the logo and favicon to media library and paste the URL below.</p> 
Logo<br><input type="text" size="50" id="logo_image" name="softlights-options[logo]" value="<?php echo esc_url($softlights_options['logo']); ?>"> 
<input id="logo_button" type="button" value="Upload Image" /> (200x90px - only transparent PNG) 
<br>
Favicon <br><input size="50" id="favicon_image" type="text" name="softlights-options[favicon]" value="<?php echo esc_url($softlights_options['favicon']); ?>"><input id="favicon_button" type="button" value="Upload Image" /> <br>
Footer Copyright Text <br><input type="text" size="50" name="softlights-options[footer]" value="<?php echo esc_attr($softlights_options['footer']); ?>"> (optional)<br><br>
<h2>Social Share Links</h2>
Facebook url: <br><input type="text" size="50" name="softlights-options[facebook-link]" value="<?php echo esc_url($softlights_options['facebook-link']); ?>"><br>
Twitter url <br><input type="text" size="50" name="softlights-options[twitter-link]" value="<?php echo esc_url($softlights_options['twitter-link']); ?>"><br>
Google plus url <br><input type="text" size="50" name="softlights-options[google-plus-link]" value="<?php echo esc_url($softlights_options['google-plus-link']); ?>"><br>
Pin it url <br><input type="text" size="50" name="softlights-options[pin-it-link]" value="<?php echo esc_url($softlights_options['pin-it-link']); ?>"><br>
Linked in <br><input type="text" size="50" name="softlights-options[linkedin-link]" value="<?php echo esc_url($softlights_options['linkedin-link']); ?>"><br><br>
<h2>Comment Settings</h2>
<p>You can chose to completely disable comments and comment form in this theme. If you receive spam and hate comments, disable it. Enabled by default.</p>
<p><input type="checkbox" name="softlights-options[comments]" value="1" <?php if(isset($softlights_options['comments'])) { checked(absint($softlights_options['comments']),1); }?>> Enable/Disable Comments in Posts/Pages <p>

</div>				

<input type="radio" name="tab" id="two">
<div id="tab2" class="tab">
           
					<h2>Showcase Box Settings </h2>
<p><input type="checkbox" name="softlights-options[showcase]" value="1" <?php if(isset($softlights_options['showcase'])) { checked(absint($softlights_options['showcase']),1); }?>> Enable/Disable Showcasebox Box <p>

Showcase Image (optional):<br><input id="showcase_image" type="text" size="50" name="softlights-options[showcase-image]" value="<?php echo esc_url($softlights_options['showcase-image']); ?>"><input id="showcase_button" type="button" value="Upload Image" /> (works any size- try big sizes like 300x300)<br><br>
Showcase Title (optional): <br><input type="text" size="50" name="softlights-options[showcase-title]" value="<?php echo esc_attr($softlights_options['showcase-title']); ?>"><br><br>
Showcase Text (optional) <br><textarea rows="4" cols="50" name="softlights-options[showcase-text]"><?php echo esc_attr($softlights_options['showcase-text']); ?></textarea><br><br>
Link URL (optional): <br><input type="text" size="50" name="softlights-options[showcase-link]" value="<?php echo esc_url($softlights_options['showcase-link']); ?>"><br><br>

<h2>Showcasebox Background Color</h2>
<p>Makes changes to background color to showcasebox.
<input type="text" name="softlights-options[showcase-color]" class='color-picker' id="color-picker-8"
style="background:<?php echo $softlights_options['showcase-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['showcase-color']);  ?>" /></p>

<h2>Showcasebox Font Color</h2>
<p>Makes changes to font color to showcasebox.
<input type="text" name="softlights-options[showcase-font-color]" class='color-picker' id="color-picker-8"
style="background:<?php echo $softlights_options['showcase-font-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['showcase-font-color']);  ?>" /></p>

</div>
							
<input type="radio" name="tab" id="three">
			
<div id="tab3" class="tab" >

<h2>Theme Color Settings</h2>
<p>Dont be afraid to type 'transparent' in the below color values, if you prefer transparency</p>



<h2>Theme Background Body Color</h2>
<p>Sets the background of the entire site.
<input type="text" name="softlights-options[bg-color]" class='color-picker' id="color-picker-7"
style="background:<?php echo $softlights_options['bg-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['bg-color']);  ?>" /></p>

<h2>Navigation Menu Background Color:</h2>
<p>Changes the background of navigation menu (primary menu) 
<input type="text" name="softlights-options[menu-color]" 
style="background:<?php echo $softlights_options['menu-color']; ?>" class='color-picker' id="color-picker-1"
value="<?php echo esc_attr($softlights_options['menu-color']); ?>" /></p>

<h2>Navigation Menu - Font Color</h2>
<p>This changes only the font color to align with above nav background color  
<input type="text" name="softlights-options[menu-font-color]" 
style="background:<?php  echo $softlights_options['menu-font-color']; ?>" class='color-picker' id="color-picker-3"
value="<?php echo esc_attr($softlights_options['menu-font-color']); ?>" /></p>

<h2>Header Background Color</h2>
<p>Changes the background of the header: 
<input type="text" name="softlights-options[header-color]" class='color-picker' id="color-picker-2"
style="background:<?php echo $softlights_options['header-color']; ?>" 
value="<?php  echo esc_attr($softlights_options['header-color']);  ?>" /></p>

<h2>Footer Background Color</h2>
<p>Changes the background color of the footer:
<input type="text" name="softlights-options[footer-color]" class='color-picker' id="color-picker-4"
style="background:<?php echo $softlights_options['footer-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['footer-color']); ?>" /></p>

<h2>All Widgets Background Color</h2>
<p>Makes changes to background color of all widgets.
<input type="text" name="softlights-options[widgets-menus-color]" class='color-picker' id="color-picker-5"
style="background:<?php echo $softlights_options['widgets-menus-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['widgets-menus-color']);  ?>" /></p>


<p>Note: Type transparent for transparency instead of a fixed color. To reset to default color values, simple delete all the color values and hit submit.</p>

</div>

<input type="radio" name="tab" id="four">			
<div id="tab4" class="tab" >
<p> Please set the link colors to your theme</p>
<h2>1. All Sitewide Links</h2>
Makes changes to links to entire site
<input type="text" name="softlights-options[link-color]" class='color-picker' id="color-picker-6"
style="background:<?php echo $softlights_options['link-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['link-color']);  ?>" /></p>

<h2>2. Single Post/Page Link color </h2>
This is specific link color, occurs only inside page or post content.
<input type="text" name="softlights-options[content-link-color]" class='color-picker' id="color-picker-7"
style="background:<?php echo $softlights_options['content-link-color'];  ?>" 
value="<?php echo esc_attr($softlights_options['content-link-color']);  ?>" />


</div>

<?php submit_button(); ?> 
</form>
<h2>Reset Defaults</h2>
<form method="post" action="">
	<p class="submit">
	Load theme default settings: <input name="reset" class="button button-secondary"  type="submit" value="Reset to theme default settings" >
		<input type="hidden" name="action" value="reset" />
	</p>
</form>
</div>

<?php
}
?>